<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Photo Gallery directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2016.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	M. Carroll 
Custom Field Type:
	Photo Upload Link Field
Name:
	photo_upload_link_render.cfc
Summary:
	Custom select field to render an upload link to the photo element.
ADF App:
	pt_photo_gallery
History:
	2009-08-04 - MFC - Created
	2010-04-30 - MFC - Update the CFT for the ADF Lightbox
	2010-08-19 - MFC - Updated the load JQuery and JQuery versions to use the global versioning.
	2011-04-26 - MFC - Updated '_loadImage' function for Forms_1_1 callback functionality.
	2012-04-27 - MFC - Added option into the Photo Upload CFT to directly upload
						a photo or display the full photo form to the user.
	2012-07-05 - MFC - Added option to set the field value to store.
						Added field validation and security.
	2012-07-05 - MFC - Added options to enter the "Photo ID" and "Photo Upload" field names.
	2012-07-24 - MFC - Updated for the Upload Dialog form callback.
	2012-07-27 - MFC - Updated font size to standardize around the "upload" anchor tag.
	2015-02-13 - DMB - Added decipherCPPAGEID to fix up upload_form_url field which changed with the CommonSpot extended URL field change.
	2015-07-13 - DJM - Converted to CFC
	2016-02-26 - DRM - Resource detection support
--->
<cfcomponent displayName="PhotoUploadLink Render" extends="ADF.extensions.customfields.adf-form-field-renderer-base">

<cffunction name="renderControl" returntype="void" access="public">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		var currentValue = arguments.value;	// the field's current value
		var readOnly = (arguments.displayMode EQ 'readonly') ? true : false;
		var appConfig = application.ptPhotoGallery.getAppConfig();
		var currPhotoID = currentValue;
		
		inputParameters = setDefaultParameters(argumentCollection=arguments);
		
		// If storing the PHOTO URL value, then get the PHOTO ID for the record
		if ( inputParameters.photoFieldStore EQ "photoURL" )
			currPhotoID = application.ptPhotoGallery.photoService.getPhotoIDByOriginalPath(currentValue);		
		renderJSFunctions(argumentCollection=arguments,fieldParameters=inputParameters,currentPhotoID=currPhotoID);
	</cfscript>
	<cfoutput>
		<div id="#arguments.fieldName#_photoDisplay">
			<img id="#arguments.fieldName#_photoTag" src="" />
			[<a href="javascript:;" id="#arguments.fieldName#_photoRemove" onclick="#arguments.fieldName#_clearField();">Remove</a>]
		</div>
		<div id="#arguments.fieldName#_addPhoto">
			<cfif inputParameters.photoFormRender EQ "form">
				[<a href='javascript:;' onclick='#arguments.fieldName#_addPhotoForm();'>Add Photo</a>]
			<cfelse>
				[<a href='javascript:;' onclick='#arguments.fieldName#_openUploadDialog();'>Add Photo</a>]
			</cfif>
		</div>
		<input type="hidden" id="#inputParameters.photoFieldID#" name="#arguments.fieldName#" value="#currentValue#">
	</cfoutput>
</cffunction>

<cffunction name="renderJSFunctions" returntype="void" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfargument name="fieldParameters" type="struct" required="yes">
	<cfargument name="currentPhotoID" type="string" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.fieldParameters);
		var currentValue = arguments.value;
		var currPhotoID = arguments.currentPhotoID;
	</cfscript>
<cfoutput>
<script type="text/javascript">
<!--
// Store the current value and Photo ID into JS variables
var #arguments.fieldName#currentValue = "#currentValue#";
var #arguments.fieldName#currPhotoID = "#currPhotoID#";

jQuery(function(){
	
	// if currentValue has data, then photo has been uploaded already
	if (#arguments.fieldName#currentValue != "") 
		#arguments.fieldName#_handleRenderThumbnail();
	else
		#arguments.fieldName#_loadAddButton();
});

function #arguments.fieldName#_loadAddButton()
{
	jQuery("###arguments.fieldName#_photoDisplay").hide();
	jQuery("###arguments.fieldName#_addPhoto").show();
}

function #arguments.fieldName#_loadImage(photoUID)
{
	// get the photo URL
	jQuery.get( '#application.ADF.ajaxProxy#',
	{ 	
		bean: 'photoService',
		method: 'getPhotoURLbyPhotoID',
		photoID: photoUID,
		size: "_system_resize"
	},
	function(photoURL){
		// load new img url into the img field
		if (photoURL != ""){
			#arguments.fieldName#renderPhoto(photoURL);
			// Resize the Lightbox
			lbResizeWindow();
		}
		else 
		{
			// The photo doesn't exist anymore
			#arguments.fieldName#_loadAddButton();
			jQuery("input###inputParameters.photoFieldID#").val("");
		}
	});
	
	// Resize the Lightbox
	lbResizeWindow();
}

// Set the value back from the photo form
// 	2011-04-26 - MFC - Updated function for Forms_1_1 callback functionality.
function #arguments.fieldName#setPhotoField(photoFormData)
{
	// If the PHOTOID is stored, then call the load image function
	if ( "#inputParameters.photoFieldStore#" == "photoID" ) {
		jQuery("input###inputParameters.photoFieldID#").val(photoFormData['#inputParameters.photoIDNameField#']);
		#arguments.fieldName#currPhotoID = photoFormData['#inputParameters.photoIDNameField#'];
	}
	// If the photo path is stored, check for the "original" in the path
	else if ( "#inputParameters.photoFieldStore#" == "photoURL" ) {
		jQuery("input###inputParameters.photoFieldID#").val(photoFormData['#inputParameters.photoUploadNameField#']);
	}
	
	// Update the local variable for the photo ID
	#arguments.fieldName#currPhotoID = photoFormData['#inputParameters.photoUploadNameField#'];
	
	// Load new img url into the img field
	#arguments.fieldName#_handleRenderThumbnail();
}

// Handle the callback from the Upload Dialog form.
function #arguments.fieldName#uploadDialogCallback(photoFormData){
    //alert("Do uploadDialogCallback!!");
    //console.log(photoFormData);

	// Take the JSON encoded string and make a JSON object
	#arguments.fieldName#setPhotoField(jQuery.parseJSON(photoFormData));
}

function #arguments.fieldName#renderPhoto(url){
	// load new img url into the img field
	jQuery("img###arguments.fieldName#_photoTag").attr('src',url);
	jQuery("img###arguments.fieldName#_photoTag").attr('width','50');
	jQuery("img###arguments.fieldName#_photoTag").attr('height','50');
	jQuery("###arguments.fieldName#_photoDisplay").show();
	jQuery("###arguments.fieldName#_addPhoto").hide();
	// Resize the Lightbox
	lbResizeWindow();
}

// Function to clear the selected photo field
function #arguments.fieldName#_clearField()
{
	
	// Get the value for the field value
	//var currentPhotoUID = jQuery("input###inputParameters.photoFieldID#").val();
	var currentPhotoUID = #arguments.fieldName#currPhotoID;
	if (currentPhotoUID != "") {
		// confirmation to clear the image
		var clear = confirm("Attention: This photo will be deleted without saving the form.\n\nAre you sure you want to delete this document?");
		if (clear){
			
			// Delete the file record
			jQuery.get( '#application.ADF.ajaxProxy#',
			{ 	
				bean: 'photoService',
				method: 'deletePhotoUID',
				photoUID: currentPhotoUID
			},
			function(msg){
				if (msg == "true"){
					// Clear the field value
					jQuery("input###arguments.fieldName#").val("");
					// clear the photo id field
					jQuery("input###inputParameters.photoFieldID#").val("");
					#arguments.fieldName#_loadAddButton();
				}
			});
		}
	}
	else {
		// Clear the field value
		jQuery("input###arguments.fieldName#").val("");
		// clear the photo id field
		jQuery("input###inputParameters.photoFieldID#").val("");
		#arguments.fieldName#_loadAddButton();
	}
}

function #arguments.fieldName#_addPhotoForm(){
	// Open the lightbox for the add form
	openLB("#application.ADF.lightboxProxy#?bean=photoForms&method=photoAddEdit&callback=#arguments.fieldName#setPhotoField&category=#inputParameters.photoCategoryID#&title=Add Photo&lbaction=close");
}

function #arguments.fieldName#_openUploadDialog(){
	// Lightbox URL string
    var lbURL = '#application.ADF.lightboxProxy#?bean=photoUploadService&method=renderPhotoUploadForm&callback=#arguments.fieldName#setPhotoField&category=#inputParameters.photoCategoryID#&fieldName=#arguments.fieldName#&formSource=uploadLinkCFT&title=Upload New Photo';
	//var lbURL = '#application.ADF.csData.decipherCPPAGEID(application.ptPhotoGallery.appConfig.UPLOAD_FORM_URL)#?callback=#arguments.fieldName#setPhotoField&category=#inputParameters.photoCategoryID#&fieldName=#arguments.fieldName#&formSource=uploadLinkCFT&title=Upload New Photo';

    // Open the upload lightbox window
	openLB(lbURL);
}

// Return function for the Upload Dialog form. 
function #arguments.fieldName#setCSURL(inArgs) {
	//alert("setCSURL");
	//alert(inArgs);
	
	// Set the new photo to display in the form
	#arguments.fieldName#renderPhoto(inArgs[0]);
	
	// Store the photo ID value into the arguments.fieldName
	jQuery("input###inputParameters.photoFieldID#").val(inArgs[1]);
	
}

function #arguments.fieldName#_handleRenderThumbnail() {
	
	// Get the current stored value
	var currPhotoVal = jQuery("input###inputParameters.photoFieldID#").val();
	
	// Check the photo field that we are storing
	// If the PHOTOID is stored, then call the load image function
	if ( "#inputParameters.photoFieldStore#" == "photoID" )
		#arguments.fieldName#_loadImage(currPhotoVal);
	// If the photo path is stored, then just display the photo
	else if ( "#inputParameters.photoFieldStore#" == "photoURL" )
		#arguments.fieldName#renderPhoto(currPhotoVal);
	
}
//-->
</script>
</cfoutput>
</cffunction>

<cffunction name="setDefaultParameters" returntype="struct" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		
		// Set the photo field ID
		if ( NOT StructKeyExists(inputParameters, "photoFieldID") OR (LEN(inputParameters.photoFieldID) LTE 0) )
			inputParameters.photoFieldID = arguments.fieldName;
		// Set the photo field ID
		if ( NOT StructKeyExists(inputParameters, "photoFormRender") OR (LEN(inputParameters.photoFormRender) LTE 0) )
			inputParameters.photoFormRender = "form";
		// Set the photo field ID
		if ( NOT StructKeyExists(inputParameters, "photoCategoryID") OR (LEN(inputParameters.photoCategoryID) LTE 0) )
			inputParameters.photoCategoryID = "";
		// Set the photo field store value
		if ( NOT StructKeyExists(inputParameters, "photoFieldStore") OR (LEN(inputParameters.photoFieldStore) LTE 0) )
			inputParameters.photoFieldStore = "photoID";
		// Set the photo field names for the photo fields
		if ( NOT StructKeyExists(inputParameters, "photoUploadNameField") OR (LEN(inputParameters.photoUploadNameField) LTE 0) )
			inputParameters.photoUploadNameField = "photo";
		if ( NOT StructKeyExists(inputParameters, "photoIDNameField") OR (LEN(inputParameters.photoIDNameField) LTE 0) )
			inputParameters.photoIDNameField = "photoID";
		
		return inputParameters;
	</cfscript>
</cffunction>

<cfscript>
	private any function getValidationJS(required string formName, required string fieldName, required boolean isRequired)
	{
		if (arguments.isRequired)
			return 'hasValue(document.#arguments.formName#.#arguments.fieldName#, "TEXT")';
		return "";
	}
	
	private string function getValidationMsg()
	{
		return "Please upload a photo.";
	}


	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "JQuery,ADFLightbox");
	}
	public string function loadResourceDependencies()
	{
		application.ptPhotoGallery.scripts.loadJQuery();
		application.ptPhotoGallery.scripts.loadADFLightbox();
	}
</cfscript>

</cfcomponent>